# V1alpha1ExecutorConfig

ExecutorConfig holds configurations of an executor container.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**service_account_name** | **str** | ServiceAccountName specifies the service account name of the executor container. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


